PyCharter - Data Contract Management
Description: Data Contract Management and Validation

# Settings

Configure PyCharter UI settings, database connections, and DLQ connections

### API Server

Configure the PyCharter API server URL that this UI will connect to

API Server URL

### Database Configuration

Configure database connection for quality checks and data validation

Enable Database

Enable database connection for quality checks

### Dead Letter Queue (DLQ) Configuration

Configure DLQ connection to collect statistics on error messages and poison messages

Enable DLQ

Enable DLQ connection for statistics collection